@@ -15,7 +15,7 @@ use Carp;
 use List::Util qw(uniq);
 use POSIX qw(strftime);
 
-our $VERSION = '0.061'; # VERSION
+our $VERSION = '0.062'; # VERSION
 
 # ABSTRACT: The common base for Archive::BagIt. This is the module for experts. ;)
 
@@ -806,7 +806,7 @@ sub create_bagit {
 
 sub create_baginfo {
     my($self) = @_; # because bag-info.txt allows multiple key-value-entries, hash is replaced
-    $self->add_or_replace_baginfo_by_key('Bagging-Date', POSIX::strftime("%Y-%m-%D", gmtime(time)));
+    $self->add_or_replace_baginfo_by_key('Bagging-Date', POSIX::strftime("%Y-%m-%d", gmtime(time)));
     $self->add_or_replace_baginfo_by_key('Bag-Software-Agent', 'Archive::BagIt <https://metacpan.org/pod/Archive::BagIt>');
     my ($octets, $streams) = $self->calc_payload_oxum();
     $self->add_or_replace_baginfo_by_key('Payload-Oxum', "$octets.$streams");
@@ -817,7 +817,7 @@ sub create_baginfo {
     open(my $BAGINFO, ">", $bag_info_path) or croak("Can't open $bag_info_path for writing: $!");
     foreach my $entry (@{ $self->bag_info() }) {
         my %tmp = %{ $entry };
-        my ($key, $value) = each %tmp;
+        my ($key, $value) = %tmp;
         if ($key =~ m/:/) { carp "key should not contain a colon! (searchkey='$key')"; }
         print($BAGINFO "$key: $value\n");
     }
@@ -901,7 +901,7 @@ Archive::BagIt::Base - The common base for Archive::BagIt. This is the module fo
 
 =head1 VERSION
 
-version 0.061
+version 0.062
 
 =head1 SYNOPSIS
 
@@ -951,7 +951,7 @@ Archive::BagIt::Base - The common base for Archive::BagIt. This is the module fo
 
 =head1 VERSION
 
-version 0.061
+version 0.062
 
 =head1 NAME
 
@@ -1261,6 +1261,9 @@ creates a bagit.txt file
 
 creates a bag-info.txt file
 
+Hint: the entries 'Bagging-Date', 'Bag-Software-Agent', 'Payload-Oxum' and 'Bag-Size' will be automagically set,
+existing values in internal bag-info representation will be overwritten!
+
 =head2 store()
 
 store a bagit-obj if bagit directory-structure was already constructed.
